eisenmp
==========

Designed to ....
   
Contents
========


.. toctree::
   :maxdepth: 2

   README
   eisenmp
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
